# $Project: polymake $$Id: polymake.spec 7586 2007-01-23 17:51:31Z gawrilow $

Summary: Algorithms around polytopes and polyhedra
Name: polymake
Version: 2.3
Release: 2%{?dist}
License: GPL
Group: Applications/Sciences/Mathematics
URL: http://www.math.tu-berlin.de/polymake/
Vendor: TU Berlin, Algorithmic and Discrete Mathematics
Packager: TU Berlin, Algorithmic and Discrete Mathematics <polymake@math.tu-berlin.de>
Icon: as3.gif
Patch1: polymake-finehallfixes.patch

%define topname %{name}-%{version}
# very badly organized as far as perl is considered so we might as well disable it all
%define __perl_requires %{nil}
Source: ftp://ftp.math.tu-berlin.de/pub/combi/polymake/%{topname}.tar.bz2
Requires: perl >= 5.8.1
BuildRequires: perl gcc-c++ gmp-devel
Obsoletes: polymake-devel
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root

%description
Polymake is a versatile tool for the algorithmic treatment of
polytopes and polyhedra.  It offers an unified interface to a wide
variety of algorithms and free software packages from the computational
geometry field, such as convex hull computation or visualization tools.

Starting with version 2, there are also applications dealing with finite
simplicial complexes and polyhedral surfaces.

Polymake is highly adaptable to individual needs.  In particular, it
has a C++/perl interface which allows the user to bind his/her own
algorithms into the common framework.

%prep
%setup -q -n %{topname}
%patch1 -p1 -b .finehallfixes

%define ProjectTop %{_builddir}/%{topname}

%build

if [ "%{_host_cpu}" = x86_64 -a "%{_target_cpu}" != x86_64 ]; then
   compile32=-m32
   link_incr="ld -melf_i386"
fi
{
   echo Cflags="$RPM_OPT_FLAGS"
   echo CXXflags="$RPM_OPT_FLAGS"
   if [ "%{_host_cpu}" = x86_64 -a "%{_target_cpu}" != x86_64 ]; then
      echo LDflags=-m32
   fi
   echo PREFIX=/usr/local
   echo Arch=
   echo ProcessDep=none
} | make configure

if [ -x /usr/bin/getconf ] ; then
    NRPROC=$(/usr/bin/getconf _NPROCESSORS_ONLN)
    if [ $NRPROC -eq 0 ] ; then
   NRPROC=1
    fi
else
    NRPROC=1
fi
# for now, fails building sometimes so not entirely safe to build in parallel
if [ $NRPROC -gt 1 ]; then
	NRPROC=2
fi

make ProjectTop=%ProjectTop -j$NRPROC ${link_incr:+LINK_INCR="$link_incr"}

echo "Building perl extensions for polymake..."
pushd perl/ext
CFLAGS="$RPM_OPT_FLAGS" perl Makefile.PL PREFIX=$RPM_BUILD_ROOT%{_prefix} 
make OPTIMIZE="$RPM_OPT_FLAGS"
popd

%install
rm -rf $RPM_BUILD_ROOT
make ProjectTop=%ProjectTop DESTDIR=$RPM_BUILD_ROOT install install-devel
perl -i -p -e 's|(Install\w+=)/usr/local|$1\$(PREFIX)|' $RPM_BUILD_ROOT/usr/local/polymake/Makefile
rm -f $RPM_BUILD_ROOT/usr/local/polymake/configured.pl

pushd perl/ext
eval `perl '-V:installarchlib'`
mkdir -p $RPM_BUILD_ROOT$installarchlib
%makeinstall DESTDIR=$RPM_BUILD_ROOT
rm -rf $RPM_BUILD_ROOT/%{_libdir}/perl5
mv $RPM_BUILD_ROOT/perlx $RPM_BUILD_ROOT/%{_libdir}/perl5

popd
rm -f `find $RPM_BUILD_ROOT -type f -name perllocal.pod -o -name .packlist`

chmod -R u+rwX $RPM_BUILD_ROOT

[ -x /usr/lib/rpm/brp-compress ] && /usr/lib/rpm/brp-compress

find $RPM_BUILD_ROOT%{_libdir}/perl5 -type f -print | \
        sed "s@^$RPM_BUILD_ROOT@@g" > %{name}-%{version}-%{release}-filelist
if [ "$(cat %{name}-%{version}-%{release}-filelist)X" = "X" ] ; then
    echo "ERROR: EMPTY FILE LIST"
    exit 1
fi

chmod -R a+rX,og-w $RPM_BUILD_ROOT

%clean
rm -rf $RPM_BUILD_ROOT

%files -f %{name}-%{version}-%{release}-filelist
%defattr(-,root,root)
%dir /usr/local/polymake
/usr/local/polymake/apps
/usr/local/polymake/modules
/usr/local/polymake/jars
/usr/local/polymake/perl
/usr/local/polymake/povray
/usr/local/polymake/scripts
/usr/local/polymake/bin
/usr/local/polymake/lib
/usr/local/polymake/support
/usr/local/polymake/doc
%config /usr/local/polymake/Makefile
%docdir /usr/local/polymake/doc

%changelog
* Sun Jul 08 2007 Josko Plazonic <plazonic@math.princeton.edu>
- removed hacks for perl support, removed prefixable install
  option, made proper perl installation, cleaned up spec file
  (added clean section and make it build as non root better)
